import 'package:dart_blocks/os_mobile_blocks/softcorp_client.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class RegisterPage extends StatelessWidget {
  RegisterPage({
    Key? key,
    required this.logo,
    required this.title,
    required this.buttonText,
    required this.emailHint,
    required this.passwordHint,
    required this.details,
    required this.onRegister,
    required this.createdBy,
    required this.secondaryColor,
    required this.repeatPasswordHint,
  }) : super(key: key);

  final String buttonText;
  final Color secondaryColor;
  final Widget title;
  final Widget logo;
  final Widget createdBy;
  final String emailHint;
  final String passwordHint;
  final String repeatPasswordHint;
  final Widget details;
  final Function onRegister;

  final emailController = TextEditingController();
  final passwordController = TextEditingController();
  final repeatPasswordController = TextEditingController();

  static const int fadeVelocity = 1000;
  static const double acceleration = 1.05;
  static const Curve curve = Curves.linear;

  @override
  Widget build(BuildContext context) {
    return CupertinoPageScaffold(
      resizeToAvoidBottomInset: false,
      navigationBar: CupertinoNavigationBar(
        automaticallyImplyMiddle: true,
        backgroundColor: Colors.transparent,
        border: null,
        middle: title,
      ),
      child: Padding(
        padding: const EdgeInsets.all(20),
        child: Column(
          children: <Widget>[
            const SizedBox(
              height: 100,
            ),
            details,
            const SizedBox(
              height: 30,
            ),
            logo,
            const SizedBox(
              height: 30,
            ),
            SizedBox(
              height: 40,
              child: CupertinoTextField(
                controller: emailController,
                prefix: Padding(
                  padding: const EdgeInsets.only(left: 7.5),
                  child: Icon(
                    CupertinoIcons.mail,
                    color: Colors.grey[400],
                  ),
                ),
                placeholder: emailHint,
                keyboardType: TextInputType.emailAddress,
              ),
            ),
            const SizedBox(
              height: 15,
            ),
            SizedBox(
              height: 40,
              child: CupertinoTextField(
                prefix: Padding(
                  padding: const EdgeInsets.only(left: 7.5),
                  child: Icon(
                    CupertinoIcons.lock,
                    color: Colors.grey[400],
                  ),
                ),
                controller: passwordController,
                obscureText: true,
                placeholder: passwordHint,
                keyboardType: TextInputType.text,
                maxLength: 80,
              ),
            ),
            const SizedBox(
              height: 15,
            ),
            SizedBox(
              height: 40,
              child: CupertinoTextField(
                prefix: Padding(
                  padding: const EdgeInsets.only(left: 7.5),
                  child: Icon(
                    CupertinoIcons.lock_circle,
                    color: Colors.grey[400],
                  ),
                ),
                controller: repeatPasswordController,
                obscureText: true,
                placeholder: repeatPasswordHint,
                keyboardType: TextInputType.text,
                maxLength: 80,
              ),
            ),
            const SizedBox(
              height: 30,
            ),
            CupertinoButton(
              color: secondaryColor,
              onPressed: () {
                if (emailController.text.isEmpty) {
                  showCupertinoDialog(
                      context: context,
                      builder: (context) {
                        return CupertinoAlertDialog(
                          title: const Text('Missing Email'),
                          content: const Text(
                              'Please provide an email to register your account'),
                          actions: <Widget>[
                            TextButton(
                                onPressed: () {
                                  Navigator.of(context).pop();
                                },
                                child: const Text('okay'))
                          ],
                        );
                      });
                  return;
                } else if (passwordController.text.isEmpty) {
                  showCupertinoDialog(
                      context: context,
                      builder: (context) {
                        return CupertinoAlertDialog(
                          title: const Text('Missing Password'),
                          content: const Text(
                              'Please provide a password in order to register your account'),
                          actions: <Widget>[
                            TextButton(
                                onPressed: () {
                                  Navigator.of(context).pop();
                                },
                                child: const Text('okay'))
                          ],
                        );
                      });
                  return;
                }
                SoftcorpClient.userBlock
                    .login(
                        password: passwordController.text,
                        email: emailController.text)
                    .catchError((err) => {
                          passwordController.text = "",
                          emailController.text = "",
                          showCupertinoDialog(
                              context: context,
                              builder: (context) {
                                return CupertinoAlertDialog(
                                  title:
                                      const Text('Invalid email or password'),
                                  content: const Text(
                                      'An error occurred. Your email or password is probably incorrect.'),
                                  actions: <Widget>[
                                    TextButton(
                                        onPressed: () {
                                          Navigator.of(context).pop();
                                        },
                                        child: const Text('okay'))
                                  ],
                                );
                              })
                        })
                    .then((user) => {onRegister()});
              },
              child: Text(buttonText),
            ),
            const Spacer(),
            createdBy,
          ],
        ),
      ),
    );
  }
}
